@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use namespace::autoclean -also => [ qw( create ) ];
 
-our $VERSION = '0.006008'; # VERSION
+our $VERSION = '0.006009'; # VERSION
 
 use Moose;
 extends 'Business::CyberSource::Message';
@@ -48,18 +48,40 @@ has request_token => (
 	isa      => subtype( NonEmptySimpleStr, where { length $_ <= 256 }),
 );
 
-has accepted => (
-	required => 0,
-	lazy     => 1,
+has is_success => (
+	isa      => 'Bool',
 	is       => 'ro',
-	isa      => Bool,
-	alias    => [ qw( is_success is_accepted ) ],
+	lazy     => 1,
+	init_arg => undef,
 	default  => sub {
 		my $self = shift;
 		return $self->decision eq 'ACCEPT' ? 1 : 0;
 	},
 );
 
+has is_accept => (
+	isa      => 'Bool',
+	is       => 'ro',
+	lazy     => 1,
+	init_arg => undef,
+	alias    => [ qw( accepted is_accepted ) ],
+	default  => sub {
+		my $self = shift;
+		return $self->decision eq 'ACCEPT' ? 1 : 0;
+	},
+);
+
+has is_reject => (
+	isa      => 'Bool',
+	is       => 'ro',
+	lazy     => 1,
+	init_arg => undef,
+	default  => sub {
+		my $self = shift;
+		return $self->decision eq 'REJECT' ? 1 : 0;
+	},
+);
+
 sub _build_reason_text {
 	my $self = shift;
 
@@ -161,7 +183,7 @@ Business::CyberSource::Response - Response Object
 
 =head1 VERSION
 
-version 0.006008
+version 0.006009
 
 =head1 DESCRIPTION
 
@@ -215,10 +237,20 @@ Request token data created by CyberSource for each reply. The field is an
 encoded string that contains no confidential information, such as an account
 or card verification number. The string can contain up to 256 characters.
 
-=head2 accepted
+=head2 is_accept
 
 boolean way of determining whether the transaction was accepted
 
+=head2 is_reject
+
+boolean way of determining whether the transaction was rejected
+
+=head2 is_success
+
+boolean way of determining whether the transaction was successful.
+Currently an alias for L<is_accept|/"is_accept"> but will later mean a non
+error status.
+
 =head2 amount
 
 Type: Num
